tabstats: tabstats: A Lightweight Toolkit for Displaying Customizable...

tabstatsR Documentation

tabstats: A Lightweight Toolkit for Displaying Customizable Tables

Description

logo

A lightweight toolkit that provides functions for printing tables from input data in the R console or terminal with customizable formatting. Supported outputs include American Psychological Association (APA)-style tables (American Psychological Association, 2020, ISBN:9781433832178), correlation matrices, contingency tables, and two-column summary tables.

Author(s)

Maintainer: Joshua Marie joshua.marie.k@gmail.com

See Also

Useful links:


tabstats documentation built on July 8, 2026, 5:07 p.m.