td_style: Style specification for table_default()

View source: R/style-helpers.R

td_styleR Documentation

Style specification for table_default()

Description

Constructs a validated style object for use with table_default().

Usage

td_style(...)

Arguments

...

Named style entries. Each name must be a column name, a column index as a string (e.g. "1"), or "title". Each value is a string or a function ⁠\(ctx) ...⁠ where ctx is a context list.

Value

An object of class c("td_style", "tabstats_style").

Examples

td_style(mpg = "cyan", cyl = "magenta")
td_style(mpg = \(ctx) cli::col_red(ctx$value), title = "bold")


tabstats documentation built on July 8, 2026, 5:07 p.m.