View source: R/style-helpers.R
| sm_style | R Documentation |
Constructs a validated style object for use with table_summary().
sm_style(
left_col = NULL,
right_col = NULL,
border_text = NULL,
title = NULL,
sep = NULL
)
left_col |
Style for the left column. A string (e.g. |
right_col |
Style for the right column. |
border_text |
Style for the horizontal border lines. |
title |
Style for the title text. |
sep |
A single character used as the column separator (e.g. |
An object of class c("sm_style", "tabstats_style").
sm_style(left_col = "blue_bold", right_col = "green", title = "bold")
sm_style(left_col = \(x) cli::col_red(x), sep = "|")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.