View source: R/style-helpers.R
| td_style | R Documentation |
Constructs a validated style object for use with table_default().
td_style(...)
... |
Named style entries. Each name must be a column name, a column
index as a string (e.g. |
An object of class c("td_style", "tabstats_style").
td_style(mpg = "cyan", cyl = "magenta")
td_style(mpg = \(ctx) cli::col_red(ctx$value), title = "bold")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.